(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    109917,       3127]
NotebookOptionsPosition[    105641,       3042]
NotebookOutlinePosition[    105994,       3058]
CellTagsIndexPosition[    105951,       3055]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Asymptotic Equipartition Property", "Section",
 CellChangeTimes->{{3.783873521589477*^9, 
  3.7838735267938004`*^9}},ExpressionUUID->"70087fbf-0e89-417d-ba20-\
63ff4cd12053"],

Cell[CellGroupData[{

Cell["General functions", "Subsection",
 CellChangeTimes->{{3.7838736214044733`*^9, 
  3.783873622996605*^9}},ExpressionUUID->"89d0214f-4f0c-4739-beae-\
a4931150f1ad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", "ps_", "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "p"}], "*", 
     RowBox[{"Log", "[", 
      RowBox[{"2", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "ps"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.783874338408979*^9, 3.783874348147831*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"0cea4ccf-0b4f-4c1c-89c3-8105db63e390"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TF", "[", "xs_", "]"}], ":=", 
  RowBox[{"TableForm", "[", 
   RowBox[{"xs", ",", 
    RowBox[{"TableDepth", "\[Rule]", "2"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.783873626704619*^9, 3.783873635435176*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"efe4a758-c5b4-41dc-b3fa-afb9735a414d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AllProducts", "[", 
   RowBox[{"xs_", ",", "0"}], "]"}], ":=", " ", 
  RowBox[{"{", "1", "}"}]}]], "Input",
 CellChangeTimes->{{3.783873636771934*^9, 3.783873655593793*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"ff5aebbb-0945-4141-a9f1-8fe8a4424024"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AllProducts", "[", 
   RowBox[{"xs_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"x", "*", "p"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xs"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", 
        RowBox[{"AllProducts", "[", 
         RowBox[{"xs", ",", 
          RowBox[{"r", "-", "1"}]}], "]"}]}], "}"}]}], "]"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.783873657289963*^9, 3.7838736852672586`*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"04bd128e-7b7a-4cad-8c70-34ef743a53a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Given a probability distribution (p_1,...,p_c) on a source, find the \
probabilities of all words of length r.\
\>", "Subsection",
 CellChangeTimes->{{3.783873529214239*^9, 3.783873536702303*^9}, {
  3.783873567110771*^9, 
  3.783873586708475*^9}},ExpressionUUID->"c36c9157-9777-48f3-a1e5-\
0165db485b68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilities", "[", 
   RowBox[{"ps_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"AllProducts", "[", 
   RowBox[{"ps", ",", "r"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7838739475630302`*^9, 3.783873953580737*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"87e06c5f-88e3-4d09-9389-bc3e120ca97f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilitiesTallied", "[", 
   RowBox[{"ps_", ",", 
    RowBox[{"r_:", "1"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AllProducts", "[", 
       RowBox[{"ps", ",", "r"}], "]"}], "//", "Tally"}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}], "//", 
   "Reverse"}]}]], "Input",
 CellChangeTimes->{{3.7838735888497477`*^9, 3.783873617417326*^9}, {
  3.783873715218213*^9, 3.78387371543878*^9}, {3.783873748533074*^9, 
  3.7838737804286623`*^9}, {3.78387394627487*^9, 3.783873946972734*^9}, {
  3.783874194229772*^9, 3.783874225696313*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"9f07babd-e9c0-46fe-8f57-5c673203f47f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilitiesFull", "[", 
   RowBox[{"ps_", ",", "r_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"SortBy", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
         RowBox[{"x", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", " ", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "*", 
          RowBox[{"x", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"WordProbabilitiesTallied", "[", 
          RowBox[{"ps", ",", "r"}], "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}], "//", 
   "Reverse"}]}]], "Input",
 CellChangeTimes->{{3.783873785190579*^9, 3.783873918812958*^9}, {
  3.783873958116802*^9, 3.7838739587822247`*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"c852711b-a00a-40da-b485-266144c1f20c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example (like Example 11.2): alphabet {0, 1} with probabilities {2/5,3/5}\
\>", "Subsection",
 CellChangeTimes->{{3.783874029752055*^9, 3.7838740484777393`*^9}, {
  3.78387600579788*^9, 3.783876010401516*^9}, {3.783876242446932*^9, 
  3.783876263594768*^9}},ExpressionUUID->"7a020644-ef0d-47bd-8c8d-\
1494aa812ef9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "/", "5"}], ",", 
     RowBox[{"3", "/", "5"}]}], "}"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.783874359385517*^9, 3.783874368886195*^9}, {
  3.783876013365848*^9, 3.7838760198359623`*^9}, {3.7838760991543083`*^9, 
  3.7838761046577597`*^9}, {3.7838762459588842`*^9, 3.783876248084009*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"5cf7787c-4840-4dd2-bf50-6f4f432a144a"],

Cell[BoxData["0.9709505944546687`"], "Output",
 CellChangeTimes->{
  3.783874369798904*^9, {3.78387601795128*^9, 3.783876020121787*^9}, 
   3.783876105092971*^9, 3.78387624841115*^9, 3.783920020724598*^9, 
   3.78392005972373*^9, 3.784282917874916*^9, 3.784308585513412*^9, 
   3.7845353365586853`*^9, 3.7850015987292233`*^9},
 CellLabel->
  "Out[111]=",ExpressionUUID->"b0fbaa67-083a-4a96-bb4a-91d0912d8388"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
With words of length 6, the most frequent probability is 256/15625 = 0.0138, \
with 20 words. The rarest probabilities are for the word 000000 and 111111: \
note that 111111 is the most common word, but still its probability is low.\
\>", "Subsubsection",
 CellChangeTimes->{{3.783874057655398*^9, 3.783874065651038*^9}, {
  3.783874163847588*^9, 3.7838741722986097`*^9}, {3.7838742303477573`*^9, 
  3.783874266250867*^9}, {3.783876037245564*^9, 3.783876094349354*^9}, {
  3.783876129890942*^9, 
  3.783876226317347*^9}},ExpressionUUID->"7d69ae2a-1419-4f7a-86cb-\
524b0f3457f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilitiesTallied", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "/", "5"}], ",", 
      RowBox[{"3", "/", "5"}]}], "}"}], ",", "6"}], "]"}], "/.", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a_", ",", "b_"}], "}"}], "\[RuleDelayed]", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"a", "//", "N"}], ",", "b"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.78387415557294*^9, 3.783874189269045*^9}, {
   3.783876024797316*^9, 3.783876050032941*^9}, {3.783876107796073*^9, 
   3.7838761491807957`*^9}, 3.783876190021922*^9},
 CellLabel->
  "In[112]:=",ExpressionUUID->"60205792-c910-4f41-ae1b-4c6a05b8f9c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["216", "15625"], ",", "0.013824`", ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["324", "15625"], ",", "0.020736`", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["144", "15625"], ",", "0.009216`", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["486", "15625"], ",", "0.031104`", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["96", "15625"], ",", "0.006144`", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["729", "15625"], ",", "0.046656`", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["64", "15625"], ",", "0.004096`", ",", "1"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.783874155901183*^9, 3.7838742286004133`*^9}, {
   3.783876029347918*^9, 3.7838760504339542`*^9}, {3.783876114616708*^9, 
   3.78387614950282*^9}, 3.783876190489751*^9, 3.7839200208234386`*^9, 
   3.783920059807994*^9, 3.784282918193055*^9, 3.784308585597837*^9, 
   3.784535336636256*^9, 3.78500159880264*^9},
 CellLabel->
  "Out[112]=",ExpressionUUID->"d2d0e712-aea0-42a5-85b1-b6b6043bdbe2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The histogram is not so illuminating. But the powers of five suggests it \
might be better to use a logarithmic scale on the y-axis ...\
\>", "Subsubsection",
 CellChangeTimes->{{3.783874268126124*^9, 3.783874289790579*^9}, {
  3.784283909717462*^9, 
  3.78428391022602*^9}},ExpressionUUID->"d8d4b933-c733-4d04-b14e-\
3198bfe4e230"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilities", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "/", "5"}], ",", 
      RowBox[{"3", "/", "5"}]}], "}"}], ",", "6"}], "]"}], "//", 
  "Histogram"}]], "Input",
 CellChangeTimes->{
  3.783874069978156*^9, {3.783874143807795*^9, 3.783874149224824*^9}, {
   3.783876232195053*^9, 3.783876236216604*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"68c2a90e-5891-4e48-9a3d-fab32c120094"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.616], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.616], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0}, {0.005, 1.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{20.328431372549023`, 53.720588235294116`}, {
          83.39208991707699, 93.2698071497936}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.005, 0}, {0.01, 21.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{53.220588235294116`, 
          86.61274509803921}, {-104.16225473725545`, 93.2698071497936}}],
        StatusArea[#, 21]& ,
        TagBoxNote->"21"],
       StyleBox["21", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[21, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.01, 0}, {0.015, 20.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{86.11274509803921, 
          119.50490196078431`}, {-94.78453750453882, 93.2698071497936}}],
        StatusArea[#, 20]& ,
        TagBoxNote->"20"],
       StyleBox["20", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[20, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.02, 0}, {0.025, 15.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{151.89705882352942`, 
          185.28921568627453`}, {-47.895951340955705`, 93.2698071497936}}],
        StatusArea[#, 15]& ,
        TagBoxNote->"15"],
       StyleBox["15", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[15, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.03, 0}, {0.035, 6.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{217.6813725490196, 251.07352941176472`}, {
          36.503503753493874`, 93.2698071497936}}],
        StatusArea[#, 6]& ,
        TagBoxNote->"6"],
       StyleBox["6", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[6, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.045, 0}, {0.05, 1.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{316.35784313725486`, 349.75}, {83.39208991707699, 
          93.2698071497936}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.001, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0., 0.05}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.784308585749692*^9, 3.7845353369029837`*^9, 
  3.785001598972559*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"a3544533-0e30-4dcb-9589-b115d0168146"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Log", "[", 
      RowBox[{"2", ",", "#"}], "]"}]}], "&"}], "/@", 
   RowBox[{"WordProbabilities", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "/", "5"}], ",", 
       RowBox[{"3", "/", "5"}]}], "}"}], ",", "6"}], "]"}]}], "//", 
  "Histogram"}]], "Input",
 CellChangeTimes->{{3.783874294776992*^9, 3.7838743001338053`*^9}, {
  3.783876314857766*^9, 3.783876317047765*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"feb6787f-da5c-4424-89da-705a05e4477a"],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.63], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.63], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{4., 0}, {4.5, 1.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{20.369695756605267`, 62.24279423538832}, {
          84.16314448315678, 94.57151215157327}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{5., 0}, {5.5, 6.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{103.11589271417131`, 144.98899119295436`}, {
          34.621306141074356`, 94.57151215157327}}],
        StatusArea[#, 6]& ,
        TagBoxNote->"6"],
       StyleBox["6", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[6, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{5.5, 0}, {6., 15.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{144.48899119295436`, 
          186.3620896717374}, {-54.55400287467404, 94.57151215157327}}],
        StatusArea[#, 15]& ,
        TagBoxNote->"15"],
       StyleBox["15", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[15, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{6., 0}, {6.5, 20.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{185.8620896717374, 
          227.73518815052046`}, {-104.09584121675647`, 94.57151215157327}}],
        StatusArea[#, 20]& ,
        TagBoxNote->"20"],
       StyleBox["20", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[20, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{6.5, 0}, {7., 15.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{227.23518815052046`, 
          269.1082866293034}, {-54.55400287467404, 94.57151215157327}}],
        StatusArea[#, 15]& ,
        TagBoxNote->"15"],
       StyleBox["15", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[15, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{7., 0}, {7.5, 6.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{268.6082866293034, 310.48138510808644`}, {
          34.621306141074356`, 94.57151215157327}}],
        StatusArea[#, 6]& ,
        TagBoxNote->"6"],
       StyleBox["6", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[6, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{7.5, 0}, {8., 1.}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{309.98138510808644`, 351.8544835868695}, {
          84.16314448315678, 94.57151215157327}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{3.92, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{4., 8.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7843085858099823`*^9, 3.7845353369661493`*^9, 
  3.785001599043622*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"171a3f67-3e68-49fa-9183-245b3c1dfa0f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Asymptotic Equipartition Property predicts that the distribution for \
words of length r is concentrated around rH(2/5,3/5) = 0.97r, so about r.\
\>", "Subsubsection",
 CellChangeTimes->{{3.783874306406145*^9, 3.783874335244405*^9}, {
  3.7838743735935698`*^9, 3.783874377999783*^9}, {3.783876322554954*^9, 
  3.7838763369895887`*^9}},ExpressionUUID->"1fff0927-56c0-4f4d-be4f-\
51897b38e3f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExampleHistogram", "[", 
   RowBox[{"ps_", ",", "r_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Log", "[", 
       RowBox[{"2", ",", "#"}], "]"}]}], "&"}], "/@", 
    RowBox[{"WordProbabilities", "[", 
     RowBox[{"ps", ",", "r"}], "]"}]}], "//", "Histogram"}]}]], "Input",
 CellChangeTimes->{{3.783874398608426*^9, 3.783874446439879*^9}, {
  3.7838763421021767`*^9, 3.783876348903414*^9}},
 CellLabel->
  "In[115]:=",ExpressionUUID->"96a931ad-e32d-401d-bdfa-dc2e4a5ceec5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ExampleHistogram", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "/", "5"}], ",", 
       RowBox[{"3", "/", "5"}]}], "}"}], ",", "r"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "5", ",", "10", ",", "15"}], "}"}]}], 
    "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783874422738039*^9, 3.7838744592874727`*^9}, {
  3.783876353408907*^9, 3.783876395922269*^9}, {3.783920079388185*^9, 
  3.7839200796938047`*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"467ac87c-ca3c-4344-9f0c-ac10d3c778ab"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.6719999999999999], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.6719999999999999], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.5, 0}, {1., 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{19.853282626100885`, 97.93534827862291}, {-53.75,
             39.64993488820099}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1., 0}, {1.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{97.43534827862291, 175.51741393114492`}, {-53.75,
             39.64993488820099}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0.48, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{0.5, 1.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.6579999999999999], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.6579999999999999], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1., 0}, {1.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{19.78921568627451, 
            58.27941176470588}, {-7.258987194496882, 38.73202561100625}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2., 0}, {2.5, 2.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{95.76960784313724, 
            134.25980392156862`}, {-52.750000000000014`, 38.73202561100625}}],
          
          StatusArea[#, 2]& ,
          TagBoxNote->"2"],
         StyleBox["2", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2.5, 0}, {3., 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{133.75980392156862`, 
            172.24999999999997`}, {-7.258987194496882, 38.73202561100625}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0.96, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{1., 3.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.637], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.637], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3.5, 0}, {4., 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{16.848039215686242`, 39.47689075630248}, {
            29.718671237968337`, 39.49296804218704}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4., 0}, {4.5, 5.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{38.97689075630248, 
            61.60574229691872}, {-7.378515978906471, 39.49296804218704}}],
          StatusArea[#, 5]& ,
          TagBoxNote->"5"],
         StyleBox["5", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[5, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4.5, 0}, {5., 10.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{61.10574229691872, 
            83.73459383753496}, {-53.74999999999998, 39.49296804218704}}],
          StatusArea[#, 10]& ,
          TagBoxNote->"10"],
         StyleBox["10", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[10, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5., 0}, {5.5, 10.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{83.23459383753496, 
            105.8634453781512}, {-53.74999999999998, 39.49296804218704}}],
          StatusArea[#, 10]& ,
          TagBoxNote->"10"],
         StyleBox["10", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[10, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6., 0}, {6.5, 5.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{127.49229691876747`, 
            150.12114845938368`}, {-7.378515978906471, 39.49296804218704}}],
          StatusArea[#, 5]& ,
          TagBoxNote->"5"],
         StyleBox["5", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[5, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, {7., 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{149.62114845938368`, 172.24999999999994`}, {
            29.718671237968337`, 39.49296804218704}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{3.43, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{3.5, 7.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.595], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.595], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7., 0}, {7.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{22.795636509207384`, 35.00962308308186}, {
            37.33883189014656, 38.20063442785799}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, {8., 10.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{34.50962308308186, 46.72360965695634}, {
            34.08260905074367, 38.20063442785799}}],
          StatusArea[#, 10]& ,
          TagBoxNote->"10"],
         StyleBox["10", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[10, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, {9., 45.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{57.93759623083082, 70.1515828047053}, {
            21.419520230843553`, 38.20063442785799}}],
          StatusArea[#, 45]& ,
          TagBoxNote->"45"],
         StyleBox["45", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[45, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9., 0}, {9.5, 120.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{69.6515828047053, 
            81.8655693785798}, {-5.715670097513851, 38.20063442785799}}],
          StatusArea[#, 120]& ,
          TagBoxNote->"120"],
         StyleBox["120", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[120, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9.5, 0}, {10., 210.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{81.3655693785798, 
            93.57955595245429}, {-38.27789849154273, 38.20063442785799}}],
          StatusArea[#, 210]& ,
          TagBoxNote->"210"],
         StyleBox["210", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[210, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10., 0}, {10.5, 252.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{93.07955595245429, 
            105.29354252632876`}, {-53.47360507542287, 38.20063442785799}}],
          StatusArea[#, 252]& ,
          TagBoxNote->"252"],
         StyleBox["252", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[252, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10.5, 0}, {11., 210.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{104.79354252632876`, 
            117.00752910020327`}, {-38.27789849154273, 38.20063442785799}}],
          StatusArea[#, 210]& ,
          TagBoxNote->"210"],
         StyleBox["210", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[210, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11., 0}, {11.5, 120.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{116.50752910020327`, 
            128.72151567407775`}, {-5.715670097513851, 38.20063442785799}}],
          StatusArea[#, 120]& ,
          TagBoxNote->"120"],
         StyleBox["120", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[120, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12., 0}, {12.5, 45.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{139.93550224795223`, 152.1494888218267}, {
            21.419520230843553`, 38.20063442785799}}],
          StatusArea[#, 45]& ,
          TagBoxNote->"45"],
         StyleBox["45", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[45, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12.5, 0}, {13., 10.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{151.6494888218267, 163.8634753957012}, {
            34.08260905074367, 38.20063442785799}}],
          StatusArea[#, 10]& ,
          TagBoxNote->"10"],
         StyleBox["10", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[10, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13., 0}, {13.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{163.3634753957012, 175.57746196957567`}, {
            37.33883189014656, 38.20063442785799}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{6.87, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{7., 13.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.5599999999999999], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.5599999999999999], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11., 0}, {11.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{27.661764705882348`, 36.25}, {35.08948368316187, 
            35.60302939417095}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11.5, 0}, {12., 15.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{35.75, 44.33823529411765}, {34.899843729034714`, 
            35.60302939417095}}],
          StatusArea[#, 15]& ,
          TagBoxNote->"15"],
         StyleBox["15", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[15, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12., 0}, {12.5, 105.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{43.83823529411765, 52.426470588235276`}, {
            33.68072973821726, 35.60302939417095}}],
          StatusArea[#, 105]& ,
          TagBoxNote->"105"],
         StyleBox["105", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[105, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12.5, 0}, {13., 455.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{51.926470588235276`, 60.51470588235293}, {
            28.93973088503827, 35.60302939417095}}],
          StatusArea[#, 455]& ,
          TagBoxNote->"455"],
         StyleBox["455", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[455, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13., 0}, {13.5, 1365.}, "RoundingRadius" -> 0]},
           ImageSizeCache->{{60.01470588235293, 68.60294117647058}, {
            16.613133866772905`, 35.60302939417095}}],
          StatusArea[#, 1365]& ,
          TagBoxNote->"1365"],
         StyleBox["1365", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1365, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13.5, 0}, {14., 3003.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{68.10294117647058, 
            76.69117647058823}, {-5.574740766104753, 35.60302939417095}}],
          StatusArea[#, 3003]& ,
          TagBoxNote->"3003"],
         StyleBox["3003", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[3003, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{14.5, 0}, {15., 5005.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{84.27941176470588, 
            92.86764705882351}, {-32.693254206288564`, 35.60302939417095}}],
          StatusArea[#, 5005]& ,
          TagBoxNote->"5005"],
         StyleBox["5005", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[5005, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{15., 0}, {15.5, 6435.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{92.36764705882351, 
            100.95588235294116`}, {-52.06362094927699, 35.60302939417095}}],
          StatusArea[#, 6435]& ,
          TagBoxNote->"6435"],
         StyleBox["6435", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[6435, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{15.5, 0}, {16., 6435.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{100.45588235294116`, 
            109.04411764705881`}, {-52.06362094927699, 35.60302939417095}}],
          StatusArea[#, 6435]& ,
          TagBoxNote->"6435"],
         StyleBox["6435", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[6435, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{16., 0}, {16.5, 5005.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{108.54411764705881`, 
            117.13235294117644`}, {-32.693254206288564`, 35.60302939417095}}],
          
          StatusArea[#, 5005]& ,
          TagBoxNote->"5005"],
         StyleBox["5005", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[5005, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{16.5, 0}, {17., 3003.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{116.63235294117644`, 
            125.22058823529412`}, {-5.574740766104753, 35.60302939417095}}],
          StatusArea[#, 3003]& ,
          TagBoxNote->"3003"],
         StyleBox["3003", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[3003, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{17., 0}, {17.5, 1365.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{124.72058823529412`, 133.30882352941174`}, {
            16.613133866772905`, 35.60302939417095}}],
          StatusArea[#, 1365]& ,
          TagBoxNote->"1365"],
         StyleBox["1365", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1365, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{18., 0}, {18.5, 455.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{140.89705882352942`, 149.48529411764704`}, {
            28.93973088503827, 35.60302939417095}}],
          StatusArea[#, 455]& ,
          TagBoxNote->"455"],
         StyleBox["455", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[455, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{18.5, 0}, {19., 105.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{148.98529411764704`, 157.57352941176467`}, {
            33.68072973821726, 35.60302939417095}}],
          StatusArea[#, 105]& ,
          TagBoxNote->"105"],
         StyleBox["105", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[105, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{19., 0}, {19.5, 15.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{157.07352941176467`, 165.66176470588235`}, {
            34.899843729034714`, 35.60302939417095}}],
          StatusArea[#, 15]& ,
          TagBoxNote->"15"],
         StyleBox["15", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[15, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{19.5, 0}, {20., 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{165.16176470588235`, 173.74999999999997`}, {
            35.08948368316187, 35.60302939417095}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{10.82, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{11., 20.}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.7843085868786373`*^9, 3.784535338452751*^9, 
  3.785001600244545*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"6365cd16-e61e-4842-970f-2291a67149ae"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Similar example: alphabet {a, t, g, c} with probabilities {1/8, 1/8, 1/4, \
1/2}. Convergence is a bit smoother.\
\>", "Subsection",
 CellChangeTimes->{{3.783874029752055*^9, 3.7838740484777393`*^9}, {
  3.783876409368106*^9, 
  3.783876416303504*^9}},ExpressionUUID->"448ac249-6dae-4c4b-8b57-\
a6967c21581c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "/", "8"}], ",", 
    RowBox[{"1", "/", "8"}], ",", 
    RowBox[{"1", "/", "4"}], ",", 
    RowBox[{"1", "/", "2"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.783874359385517*^9, 3.783874368886195*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"c7dc21a8-97ce-46a7-a56e-2ffcda443b8e"],

Cell[BoxData[
 FractionBox["7", "4"]], "Output",
 CellChangeTimes->{3.783874369798904*^9, 3.7842829206944733`*^9, 
  3.784308587047145*^9, 3.784535338873302*^9, 3.785001600430626*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"f9057464-e3cc-4421-9c1a-90ee2a340119"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilities", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "8"}], ",", 
      RowBox[{"1", "/", "8"}], ",", 
      RowBox[{"1", "/", "4"}], ",", 
      RowBox[{"1", "/", "2"}]}], "}"}], ",", "2"}], "]"}], "//", 
  "Tally"}]], "Input",
 CellChangeTimes->{{3.784308606428673*^9, 3.784308627391087*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"6f85c0bc-22ec-4c68-913d-70f0468f9f0d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "64"], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "32"], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "16"], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "8"], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "4"], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.784308615287821*^9, 3.784308627882326*^9}, 
   3.784535339008039*^9, 3.7850016005119743`*^9},
 CellLabel->
  "Out[118]=",ExpressionUUID->"204b7867-11db-4214-892d-3f15207d1e53"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"WordProbabilities", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "8"}], ",", 
      RowBox[{"1", "/", "8"}], ",", 
      RowBox[{"1", "/", "4"}], ",", 
      RowBox[{"1", "/", "2"}]}], "}"}], ",", "3"}], "]"}], "//", 
  "Tally"}]], "Input",
 CellChangeTimes->{{3.784309065619173*^9, 3.784309065690217*^9}},
 CellLabel->
  "In[119]:=",ExpressionUUID->"57a4c68f-aab1-467c-b880-9f9da30cd073"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "512"], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "256"], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "128"], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "64"], ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "32"], ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "16"], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "8"], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.784309066024737*^9, 3.784535339143911*^9, 
  3.7850016005956573`*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"6db6a8e3-b8f0-418b-973e-babf03bffe81"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Asymptotic Equipartition Property predicts that the distribution for \
words of length r is concentrated around rH(1/8,1/8,1/4,1/2) = 7r/4.\
\>", "Subsubsection",
 CellChangeTimes->{{3.783874306406145*^9, 3.783874335244405*^9}, {
  3.7838743735935698`*^9, 
  3.783874377999783*^9}},ExpressionUUID->"37fa2290-e728-4f97-b297-\
c5ee266ab2c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ExampleHistogram", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "/", "8"}], ",", 
       RowBox[{"1", "/", "8"}], ",", 
       RowBox[{"1", "/", "4"}], ",", 
       RowBox[{"1", "/", "2"}]}], "}"}], ",", "r"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], 
      "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.783874422738039*^9, 3.7838744592874727`*^9}, {
  3.783876451543244*^9, 3.7838764575438147`*^9}, {3.78392008669599*^9, 
  3.783920086849321*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"ca6a4de6-f200-4f40-897c-6f3d56c8b75d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.6649999999999999], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.6649999999999999], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{0.5, 0}, {1.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{19.789215686274506`, 
            70.94281045751633}, {-7.258987194496875, 38.73202561100626}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1.5, 0}, {2.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{70.44281045751633, 
            121.59640522875814`}, {-7.258987194496875, 38.73202561100626}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2.5, 0}, {3.5, 2.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{121.09640522875814`, 
            172.24999999999997`}, {-52.75000000000001, 38.73202561100626}}],
          StatusArea[#, 2]& ,
          TagBoxNote->"2"],
         StyleBox["2", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0.44, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{0.5, 3.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.651], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.651], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{1.5, 0}, {2.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{12.007005604483581`, 45.07706164931945}, {
            21.251431398390444`, 41.25178924798806}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2.5, 0}, {3.5, 2.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{44.57706164931945, 77.6471176941553}, {
            1.7510735487928315`, 41.25178924798806}}],
          StatusArea[#, 2]& ,
          TagBoxNote->"2"],
         StyleBox["2", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3.5, 0}, {4.5, 5.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{77.1471176941553, 110.21717373899115`}, {-56.75, 
            41.25178924798806}}],
          StatusArea[#, 5]& ,
          TagBoxNote->"5"],
         StyleBox["5", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[5, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4.5, 0}, {5.5, 4.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{109.71717373899115`, 
            142.787229783827}, {-37.249642150402394`, 41.25178924798806}}],
          StatusArea[#, 4]& ,
          TagBoxNote->"4"],
         StyleBox["4", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[4, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5.5, 0}, {6.5, 4.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{142.287229783827, 
            175.3572858286629}, {-37.249642150402394`, 41.25178924798806}}],
          StatusArea[#, 4]& ,
          TagBoxNote->"4"],
         StyleBox["4", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[4, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{1.4, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{1.5, 6.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.637], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.637], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{2.5, 0}, {3.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{16.910928742994393`, 39.988991192954366`}, {
            33.87563027312117, 39.632609732739006`}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3.5, 0}, {4.5, 3.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{39.488991192954366`, 62.567053642914324`}, {
            23.361671353885484`, 39.632609732739006`}}],
          StatusArea[#, 3]& ,
          TagBoxNote->"3"],
         StyleBox["3", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[3, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4.5, 0}, {5.5, 9.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{62.067053642914324`, 
            85.1451160928743}, {-8.18020540382156, 39.632609732739006`}}],
          StatusArea[#, 9]& ,
          TagBoxNote->"9"],
         StyleBox["9", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[9, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5.5, 0}, {6.5, 13.}, "RoundingRadius" -> 0]},
           ImageSizeCache->{{84.6451160928743, 
            107.72317854283426`}, {-29.20812324229292, 39.632609732739006`}}],
          
          StatusArea[#, 13]& ,
          TagBoxNote->"13"],
         StyleBox["13", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[13, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, {7.5, 18.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{107.22317854283426`, 
            130.30124099279422`}, {-55.493020540382126`, 
            39.632609732739006`}}],
          StatusArea[#, 18]& ,
          TagBoxNote->"18"],
         StyleBox["18", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[18, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, {8.5, 12.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{129.80124099279422`, 
            152.8793034427542}, {-23.951143782675082`, 39.632609732739006`}}],
          
          StatusArea[#, 12]& ,
          TagBoxNote->"12"],
         StyleBox["12", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[12, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, {9.5, 8.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{152.3793034427542, 
            175.45736589271417`}, {-2.923225944203722, 39.632609732739006`}}],
          
          StatusArea[#, 8]& ,
          TagBoxNote->"8"],
         StyleBox["8", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[8, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}}},
    
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{2.36, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{2.5, 9.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.623], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.623], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{3.5, 0}, {4.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{16.9109287429944, 34.97164398185216}, {
            37.273286352436386`, 39.46302975017069}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4.5, 0}, {5.5, 4.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{34.47164398185216, 52.5323592207099}, {
            32.20405615923347, 39.46302975017069}}],
          StatusArea[#, 4]& ,
          TagBoxNote->"4"],
         StyleBox["4", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[4, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5.5, 0}, {6.5, 14.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{52.0323592207099, 70.09307445956767}, {
            15.306622181890397`, 39.46302975017069}}],
          StatusArea[#, 14]& ,
          TagBoxNote->"14"],
         StyleBox["14", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[14, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, {7.5, 28.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{69.59307445956767, 
            87.65378969842541}, {-8.349785386389897, 39.46302975017069}}],
          StatusArea[#, 28]& ,
          TagBoxNote->"28"],
         StyleBox["28", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[28, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, {8.5, 49.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{87.15378969842541, 
            105.21450493728318`}, {-43.83439673881033, 39.46302975017069}}],
          StatusArea[#, 49]& ,
          TagBoxNote->"49"],
         StyleBox["49", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[49, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, {9.5, 56.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{104.71450493728318`, 
            122.77522017614092`}, {-55.662600522950484`, 39.46302975017069}}],
          
          StatusArea[#, 56]& ,
          TagBoxNote->"56"],
         StyleBox["56", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[56, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9.5, 0}, {10.5, 56.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{122.27522017614092`, 
            140.3359354149987}, {-55.662600522950484`, 39.46302975017069}}],
          StatusArea[#, 56]& ,
          TagBoxNote->"56"],
         StyleBox["56", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[56, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10.5, 0}, {11.5, 32.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{139.8359354149987, 
            157.89665065385643`}, {-15.10875897732712, 39.46302975017069}}],
          StatusArea[#, 32]& ,
          TagBoxNote->"32"],
         StyleBox["32", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[32, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11.5, 0}, {12.5, 16.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{157.39665065385643`, 175.4573658927142}, {
            11.927135386421785`, 39.46302975017069}}],
          StatusArea[#, 16]& ,
          TagBoxNote->"16"],
         StyleBox["16", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[16, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{3.32, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{3.5, 12.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.609], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.609], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{4.5, 0}, {5.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{22.795636509207363`, 37.1394388237863}, {
            36.89191729153684, 37.82608033679056}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5.5, 0}, {6.5, 5.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{36.6394388237863, 50.98324113836522}, {
            35.15526511052197, 37.82608033679056}}],
          StatusArea[#, 5]& ,
          TagBoxNote->"5"],
         StyleBox["5", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[5, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, {7.5, 20.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{50.48324113836522, 64.82704345294417}, {
            28.64281943171619, 37.82608033679056}}],
          StatusArea[#, 20]& ,
          TagBoxNote->"20"],
         StyleBox["20", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[20, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, {8.5, 50.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{64.32704345294417, 78.6708457675231}, {
            15.61792807410464, 37.82608033679056}}],
          StatusArea[#, 50]& ,
          TagBoxNote->"50"],
         StyleBox["50", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[50, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, {9.5, 105.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{78.1708457675231, 
            92.51464808210201}, {-8.261039414849868, 37.82608033679056}}],
          StatusArea[#, 105]& ,
          TagBoxNote->"105"],
         StyleBox["105", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[105, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9.5, 0}, {10.5, 161.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{92.01464808210201, 
            106.35845039668095`}, {-32.574169949058096`, 37.82608033679056}}],
          
          StatusArea[#, 161]& ,
          TagBoxNote->"161"],
         StyleBox["161", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[161, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10.5, 0}, {11.5, 210.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{105.85845039668095`, 
            120.20225271125989`}, {-53.8481591664903, 37.82608033679056}}],
          StatusArea[#, 210]& ,
          TagBoxNote->"210"],
         StyleBox["210", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[210, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11.5, 0}, {12.5, 200.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{119.70225271125989`, 
            134.04605502583883`}, {-49.506528713953124`, 37.82608033679056}}],
          
          StatusArea[#, 200]& ,
          TagBoxNote->"200"],
         StyleBox["200", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[200, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12.5, 0}, {13.5, 160.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{133.54605502583883`, 
            147.88985734041776`}, {-32.140006903804384`, 37.82608033679056}}],
          
          StatusArea[#, 160]& ,
          TagBoxNote->"160"],
         StyleBox["160", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[160, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13.5, 0}, {14.5, 80.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{147.38985734041776`, 161.7336596549967}, {
            2.5930367164930885`, 37.82608033679056}}],
          StatusArea[#, 80]& ,
          TagBoxNote->"80"],
         StyleBox["80", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[80, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{14.5, 0}, {15.5, 32.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{161.2336596549967, 175.57746196957564`}, {
            23.432862888671572`, 37.82608033679056}}],
          StatusArea[#, 32]& ,
          TagBoxNote->"32"],
         StyleBox["32", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[32, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{4.28, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{4.5, 15.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.595], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.595], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5.5, 0}, {6.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{22.79563650920737, 35.00962308308185}, {
            38.645150465540276`, 39.26204051618551}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, {7.5, 6.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{34.50962308308185, 46.72360965695634}, {
            38.06070021231412, 39.26204051618551}}],
          StatusArea[#, 6]& ,
          TagBoxNote->"6"],
         StyleBox["6", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[6, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, {8.5, 27.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{46.22360965695634, 58.43759623083082}, {
            35.606009148764244`, 39.26204051618551}}],
          StatusArea[#, 27]& ,
          TagBoxNote->"27"],
         StyleBox["27", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[27, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, {9.5, 80.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{57.93759623083082, 70.15158280470531}, {
            29.41083646456696, 39.26204051618551}}],
          StatusArea[#, 80]& ,
          TagBoxNote->"80"],
         StyleBox["80", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[80, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9.5, 0}, {10.5, 195.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{69.65158280470531, 81.86556937857979}, {
            15.968480640365293`, 39.26204051618551}}],
          StatusArea[#, 195]& ,
          TagBoxNote->"195"],
         StyleBox["195", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[195, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10.5, 0}, {11.5, 366.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{81.36556937857979, 
            93.57955595245429}, {-4.019718019969353, 39.26204051618551}}],
          StatusArea[#, 366]& ,
          TagBoxNote->"366"],
         StyleBox["366", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[366, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11.5, 0}, {12.5, 581.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{93.07955595245429, 
            105.29354252632876`}, {-29.151078908694203`, 39.26204051618551}}],
          
          StatusArea[#, 581]& ,
          TagBoxNote->"581"],
         StyleBox["581", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[581, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12.5, 0}, {13.5, 732.}, "RoundingRadius" -> 0]},
           ImageSizeCache->{{104.79354252632876`, 
            117.00752910020324`}, {-46.801476556124214`, 39.26204051618551}}],
          
          StatusArea[#, 732]& ,
          TagBoxNote->"732"],
         StyleBox["732", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[732, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13.5, 0}, {14.5, 780.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{116.50752910020324`, 
            128.72151567407775`}, {-52.41219898709535, 39.26204051618551}}],
          StatusArea[#, 780]& ,
          TagBoxNote->"780"],
         StyleBox["780", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[780, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{14.5, 0}, {15.5, 640.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{128.22151567407775`, 
            140.43550224795223`}, {-36.04759189676288, 39.26204051618551}}],
          StatusArea[#, 640]& ,
          TagBoxNote->"640"],
         StyleBox["640", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[640, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{15.5, 0}, {16.5, 432.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{139.93550224795223`, 
            152.1494888218267}, {-11.734461362554654`, 39.26204051618551}}],
          StatusArea[#, 432]& ,
          TagBoxNote->"432"],
         StyleBox["432", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[432, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{16.5, 0}, {17.5, 192.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{151.6494888218267, 163.8634753957012}, {
            16.319150792300988`, 39.26204051618551}}],
          StatusArea[#, 192]& ,
          TagBoxNote->"192"],
         StyleBox["192", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[192, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{17.5, 0}, {18.5, 64.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{163.3634753957012, 175.5774619695757}, {
            31.28107727489067, 39.26204051618551}}],
          StatusArea[#, 64]& ,
          TagBoxNote->"64"],
         StyleBox["64", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[64, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{5.24, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{5.5, 18.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.581], Thickness[Small]}], {}, 
      {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
       EdgeForm[{Opacity[0.581], Thickness[Small]}], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, {7.5, 1.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{27.69955964771816, 38.03142514011208}, {
            38.06898179775085, 38.59959833052769}}],
          StatusArea[#, 1]& ,
          TagBoxNote->"1"],
         StyleBox["1", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, {8.5, 7.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{37.53142514011208, 47.86329063250599}, {
            37.88528260108979, 38.59959833052769}}],
          StatusArea[#, 7]& ,
          TagBoxNote->"7"],
         StyleBox["7", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[7, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, {9.5, 35.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{47.36329063250599, 57.69515612489991}, {
            37.0280196833382, 38.59959833052769}}],
          StatusArea[#, 35]& ,
          TagBoxNote->"35"],
         StyleBox["35", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[35, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9.5, 0}, {10.5, 119.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{57.19515612489991, 67.52702161729383}, {
            34.45623093008343, 38.59959833052769}}],
          StatusArea[#, 119]& ,
          TagBoxNote->"119"],
         StyleBox["119", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[119, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{10.5, 0}, {11.5, 329.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{67.02702161729383, 77.35888710968774}, {
            28.026759046946488`, 38.59959833052769}}],
          StatusArea[#, 329]& ,
          TagBoxNote->"329"],
         StyleBox["329", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[329, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{11.5, 0}, {12.5, 721.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{76.85888710968774, 87.19075260208164}, {
            16.0250781984242, 38.59959833052769}}],
          StatusArea[#, 721]& ,
          TagBoxNote->"721"],
         StyleBox["721", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[721, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{12.5, 0}, {13.5, 1337.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{86.69075260208164, 
            97.02261809447558}, {-2.8347059921108197`, 38.59959833052769}}],
          StatusArea[#, 1337]& ,
          TagBoxNote->"1337"],
         StyleBox["1337", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1337, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{13.5, 0}, {14.5, 2045.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{96.52261809447558, 
            106.85448358686949`}, {-24.511211198115355`, 38.59959833052769}}],
          
          StatusArea[#, 2045]& ,
          TagBoxNote->"2045"],
         StyleBox["2045", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2045, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{14.5, 0}, {15.5, 2674.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{106.35448358686949`, 
            116.68634907926341`}, {-43.76901031474933, 38.59959833052769}}],
          StatusArea[#, 2674]& ,
          TagBoxNote->"2674"],
         StyleBox["2674", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2674, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{15.5, 0}, {16.5, 2884.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{116.18634907926341`, 
            126.5182145716573}, {-50.19848219788627, 38.59959833052769}}],
          StatusArea[#, 2884]& ,
          TagBoxNote->"2884"],
         StyleBox["2884", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2884, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{16.5, 0}, {17.5, 2632.}, "RoundingRadius" -> 0]},
           ImageSizeCache->{{126.0182145716573, 
            136.3500800640512}, {-42.483115938121934`, 38.59959833052769}}],
          StatusArea[#, 2632]& ,
          TagBoxNote->"2632"],
         StyleBox["2632", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[2632, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{17.5, 0}, {18.5, 1904.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{135.8500800640512, 
            146.18194555644513`}, {-20.194280076580554`, 38.59959833052769}}],
          
          StatusArea[#, 1904]& ,
          TagBoxNote->"1904"],
         StyleBox["1904", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1904, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{18.5, 0}, {19.5, 1120.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{145.68194555644513`, 156.01381104883905`}, {
            3.8090816204640205`, 38.59959833052769}}],
          StatusArea[#, 1120]& ,
          TagBoxNote->"1120"],
         StyleBox["1120", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[1120, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{19.5, 0}, {20.5, 448.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{155.51381104883905`, 165.84567654123296`}, {
            24.383391646502222`, 38.59959833052769}}],
          StatusArea[#, 448]& ,
          TagBoxNote->"448"],
         StyleBox["448", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[448, {}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{20.5, 0}, {21.5, 128.}, "RoundingRadius" -> 0]},
           
           ImageSizeCache->{{165.34567654123296`, 175.67754203362688`}, {
            34.18068213509184, 38.59959833052769}}],
          StatusArea[#, 128]& ,
          TagBoxNote->"128"],
         StyleBox["128", {}, StripOnInput -> False]],
        Annotation[#, 
         Style[128, {}], 
         "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{6.2, 0},
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLines->{None, None},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    PlotRange->{{6.5, 21.5}, {All, All}},
    PlotRangePadding->{{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7838744346522503`*^9, 3.7838744724195423`*^9}, 
   3.78387645936661*^9, 3.7839200875456667`*^9, 3.784282921182496*^9, 
   3.784308587450871*^9, 3.784535339667698*^9, 3.785001601054616*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"4d1dd829-087b-446f-a85a-3d768b1b7d0d"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.783873782258564*^9, 3.783873782677691*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"4a004e17-8017-4de9-a605-6a0df72e34ab"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 755},
WindowMargins->{{Automatic, 13}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 180, 3, 67, "Section",ExpressionUUID->"70087fbf-0e89-417d-ba20-63ff4cd12053"],
Cell[CellGroupData[{
Cell[785, 29, 167, 3, 54, "Subsection",ExpressionUUID->"89d0214f-4f0c-4739-beae-a4931150f1ad"],
Cell[955, 34, 441, 13, 30, "Input",ExpressionUUID->"0cea4ccf-0b4f-4c1c-89c3-8105db63e390"],
Cell[1399, 49, 331, 8, 30, "Input",ExpressionUUID->"efe4a758-c5b4-41dc-b3fa-afb9735a414d"],
Cell[1733, 59, 291, 7, 30, "Input",ExpressionUUID->"ff5aebbb-0945-4141-a9f1-8fe8a4424024"],
Cell[2027, 68, 642, 19, 30, "Input",ExpressionUUID->"04bd128e-7b7a-4cad-8c70-34ef743a53a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2706, 92, 315, 7, 81, "Subsection",ExpressionUUID->"c36c9157-9777-48f3-a1e5-0165db485b68"],
Cell[3024, 101, 335, 8, 30, "Input",ExpressionUUID->"87e06c5f-88e3-4d09-9389-bc3e120ca97f"],
Cell[3362, 111, 769, 20, 52, "Input",ExpressionUUID->"9f07babd-e9c0-46fe-8f57-5c673203f47f"],
Cell[4134, 133, 1083, 31, 73, "Input",ExpressionUUID->"c852711b-a00a-40da-b485-266144c1f20c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5254, 169, 325, 6, 54, "Subsection",ExpressionUUID->"7a020644-ef0d-47bd-8c8d-1494aa812ef9"],
Cell[CellGroupData[{
Cell[5604, 179, 480, 11, 30, "Input",ExpressionUUID->"5cf7787c-4840-4dd2-bf50-6f4f432a144a"],
Cell[6087, 192, 409, 7, 34, "Output",ExpressionUUID->"b0fbaa67-083a-4a96-bb4a-91d0912d8388"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6533, 204, 588, 10, 97, "Subsubsection",ExpressionUUID->"7d69ae2a-1419-4f7a-86cb-524b0f3457f2"],
Cell[CellGroupData[{
Cell[7146, 218, 675, 18, 30, "Input",ExpressionUUID->"60205792-c910-4f41-ae1b-4c6a05b8f9c1"],
Cell[7824, 238, 1221, 31, 129, "Output",ExpressionUUID->"d2d0e712-aea0-42a5-85b1-b6b6043bdbe2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9094, 275, 342, 7, 71, "Subsubsection",ExpressionUUID->"d8d4b933-c733-4d04-b14e-3198bfe4e230"],
Cell[CellGroupData[{
Cell[9461, 286, 458, 13, 30, "Input",ExpressionUUID->"68c2a90e-5891-4e48-9a3d-fab32c120094"],
Cell[9922, 301, 4696, 133, 242, "Output",ExpressionUUID->"a3544533-0e30-4dcb-9589-b115d0168146"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14655, 439, 563, 17, 30, "Input",ExpressionUUID->"feb6787f-da5c-4424-89da-705a05e4477a"],
Cell[15221, 458, 5300, 151, 243, "Output",ExpressionUUID->"171a3f67-3e68-49fa-9183-245b3c1dfa0f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20570, 615, 406, 7, 71, "Subsubsection",ExpressionUUID->"1fff0927-56c0-4f4d-be4f-51897b38e3f6"],
Cell[20979, 624, 553, 15, 30, "Input",ExpressionUUID->"96a931ad-e32d-401d-bdfa-dc2e4a5ceec5"],
Cell[CellGroupData[{
Cell[21557, 643, 649, 18, 30, "Input",ExpressionUUID->"467ac87c-ca3c-4344-9f0c-ac10d3c778ab"],
Cell[22209, 663, 29921, 838, 280, "Output",ExpressionUUID->"6365cd16-e61e-4842-970f-2291a67149ae"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52191, 1508, 319, 7, 81, "Subsection",ExpressionUUID->"448ac249-6dae-4c4b-8b57-a6967c21581c"],
Cell[CellGroupData[{
Cell[52535, 1519, 370, 10, 30, "Input",ExpressionUUID->"c7dc21a8-97ce-46a7-a56e-2ffcda443b8e"],
Cell[52908, 1531, 266, 5, 50, "Output",ExpressionUUID->"f9057464-e3cc-4421-9c1a-90ee2a340119"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53211, 1541, 453, 13, 30, "Input",ExpressionUUID->"6f85c0bc-22ec-4c68-913d-70f0468f9f0d"],
Cell[53667, 1556, 670, 21, 51, "Output",ExpressionUUID->"204b7867-11db-4214-892d-3f15207d1e53"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54374, 1582, 453, 13, 30, "Input",ExpressionUUID->"57a4c68f-aab1-467c-b880-9f9da30cd073"],
Cell[54830, 1597, 820, 27, 51, "Output",ExpressionUUID->"6db6a8e3-b8f0-418b-973e-babf03bffe81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55687, 1629, 353, 7, 71, "Subsubsection",ExpressionUUID->"37fa2290-e728-4f97-b297-c5ee266ab2c2"],
Cell[CellGroupData[{
Cell[56065, 1640, 751, 21, 30, "Input",ExpressionUUID->"ca6a4de6-f200-4f40-897c-6f3d56c8b75d"],
Cell[56819, 1663, 48592, 1368, 434, "Output",ExpressionUUID->"4d1dd829-087b-446f-a85a-3d768b1b7d0d"]
}, Open  ]],
Cell[105426, 3034, 175, 3, 30, "Input",ExpressionUUID->"4a004e17-8017-4de9-a605-6a0df72e34ab"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

